/// <reference types="react" />
import * as V from "@nexys/validation";
export declare type FormOptions<Id> = OptionSet<Id>[];
export declare type FormOptionsMap<A> = Map<keyof A, FormOptions<number | string>>;
export interface InputProps<A> {
    onChange: (v: A | undefined) => void;
    value?: A;
    errors?: string[];
    disabled?: boolean;
    placeholder?: string;
}
export interface OptionSet<A> {
    id: A;
    name: string;
}
export interface WrapperProps {
    label?: string;
    info?: string;
    children: JSX.Element | JSX.Element[];
    errors?: string[];
}
/**
 * select props for dropdowns that return either a string or number (ie. enum)
 */
export declare type InputTypeString = "text" | "email" | "password";
/**
 * select props for dropdowns that return an option set
 */
export declare type InputType = InputTypeString | "number";
export interface SelectProps<A> extends InputProps<A> {
    options: OptionSet<A>[];
}
export interface SelectOptionSetProps<A> extends InputProps<OptionSet<A>> {
    options: OptionSet<A>[];
}
export declare enum FormType {
    Number = 0,
    Text = 1,
    Select = 2,
    SelectObject = 3,
    Switch = 4
}
export interface StructureUnitCore<A, Id> {
    name: keyof A;
    label?: string;
    options?: FormOptions<Id>;
}
export interface StructureViewUnit<A, Id = number> extends StructureUnitCore<A, Id> {
    render?: (a: A) => string;
}
export interface FormDef<A, Id = number> extends StructureUnitCore<A, Id> {
    uiType: FormType;
    optional: boolean;
}
export interface StructureUnit<A> extends StructureViewUnit<A> {
    uiType?: FormType;
}
export interface FormProps<A> {
    onSuccess: (v: A) => Promise<void>;
    valueDefault?: Partial<A>;
    errors?: V.Type.ErrorOut | V.Type.Error;
    isLoading?: boolean;
    options?: FormOptionsMap<A>;
}
export declare type ToggleProps<A> = Omit<FormProps<A>, "valueDefault" | "formDef"> & {
    data: A;
};
export declare type InputUnitProps<Id> = {
    type: FormType;
    options?: OptionSet<number | string>[];
} & InputProps<Id>;
export interface FormContentProps<A> {
    disabled: boolean;
    data: A;
    onChange: (d: string, name: keyof A) => void;
    options?: FormOptionsMap<A>;
}
export interface FormUIProps<A> {
    data: Partial<A>;
    errors?: V.Type.ErrorOut | V.Type.Error;
    onChange: (name: string, value: any) => void;
    disabled: boolean;
}
